@@ -25,6 +25,33 @@ class JenkinsFace(object):
         )
         self._settings['allow_redirects'] = False
 
+    def get_job_test(self,
+                     protocol='https',
+                     url=None,
+                     username=None,
+                     password=None,
+                     verify=False,
+                     name=None):
+        if not verify:
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+        self._endpoint = BASE_ENDPOINT.format(protocol, username, password, url)
+        self._session = requests.Session()
+        self._settings = self._session.merge_environment_settings(
+            self._endpoint, {}, None, verify, None
+        )
+        self._settings['allow_redirects'] = False
+        if not name:
+            raise Exception('Job name should not be None')
+        req = self._session.prepare_request(
+            requests.Request(
+                'GET',
+                self._job_url(GET_JOB, [name])
+            )
+        )
+        return self._get_response(
+            self._send(req)
+        )
+
     def get_job(self, name=None):
         if not name:
             raise Exception('Job name should not be None')
